@@ -148,6 +148,36 @@ muse_processing_new(const char *aName, cpl_recipe *aRecipe)
   return processing;
 } /* muse_processing_new() */
 
+/*---------------------------------------------------------------------------*/
+/**
+  @brief If  RADECSYS is found, translate to RADESYS. Remove HDRVER.
+  @param hdr is the propertlist containing the header to be adjusted
+ */
+/*---------------------------------------------------------------------------*/
+void 
+muse_processing_radecsys_fix(cpl_propertylist *hdr)
+{
+  if(hdr){
+    if(cpl_propertylist_has(hdr,"HDRVER")){
+        cpl_propertylist_erase(hdr,"HDRVER");
+    }
+    if(cpl_propertylist_has(hdr,"RADECSYS")){
+      char* val = NULL;
+      char* com = NULL;
+      val = cpl_strdup(cpl_propertylist_get_string(hdr, "RADECSYS"));
+      com = cpl_strdup(cpl_propertylist_get_comment(hdr, "RADECSYS"));
+      cpl_propertylist_update_string(hdr, "RADESYS", val);
+      cpl_propertylist_set_comment(hdr, "RADESYS", com);
+      cpl_propertylist_erase(hdr,"RADECSYS");
+      
+      cpl_free(val);
+      cpl_free(com);
+      cpl_error_reset();
+    }
+  }
+}
+
+
 /*---------------------------------------------------------------------------*/
 /**
   @brief Free the muse_processing structure.
@@ -317,8 +347,8 @@ muse_processing_setup_header(muse_processing *aProcessing,
     cpl_msg_warning(__func__, "No raw input files, no DFS product header added");
     return;
   }
-  /* save some headers which are be over overwritten by cpl_dfs, *
-   * including OBJECT and ESO.DRS.MUSE                           */
+  /* save some headers which are overwritten by cpl_dfs, *
+   * including OBJECT and ESO.DRS.MUSE                   */
   cpl_propertylist *hkeep = cpl_propertylist_new();
   cpl_propertylist_copy_property_regexp(hkeep, aHeader,
                                         MUSE_HEADERS_KEEP_REGEXP, 0);
@@ -328,6 +358,9 @@ muse_processing_setup_header(muse_processing *aProcessing,
   /* remove temporary stuff that is not meant to be saved to disk */
   cpl_propertylist_erase_regexp(aHeader, MUSE_HDR_TMP_REGEXP, 0);
 
+  /* Apply RADECSYS fix */
+  muse_processing_radecsys_fix(aHeader);
+
   /* make sure that the raw frame(s) are first in the list of used frames */
   cpl_frameset *fset = muse_frameset_sort_raw_other(aProcessing->usedframes,
                                                     aIndex, aDateObs, aSequence);
@@ -408,6 +441,9 @@ muse_processing_new_frame(muse_processing *aProcessing, int aIFU,
                           cpl_frame_type aType)
 {
   cpl_ensure(aProcessing, CPL_ERROR_NULL_INPUT, NULL);
+  /* Apply RADECSYS fix */
+  muse_processing_radecsys_fix(aHeader);
+
   muse_processing_prepare_header(aProcessing->recipe, aTag, aHeader);
   const char *prefix = cpl_propertylist_has(aHeader, "MUSE PRIVATE FILE PREFIX")
                      ? cpl_propertylist_get_string(aHeader,
@@ -494,7 +530,8 @@ muse_processing_save_image(muse_processing *aProcessing, int aIFU,
   cpl_frame *frame = muse_processing_new_frame(aProcessing, aIFU,
                                                aImage->header, aTag,
                                                CPL_FRAME_TYPE_IMAGE);
-  cpl_msg_info(__func__, "Saving image as %s", cpl_frame_get_filename(frame));
+  cpl_msg_info(__func__, "Saving image as \"%s\"",
+               cpl_frame_get_filename(frame));
   int r = muse_image_save(aImage, cpl_frame_get_filename(frame));
   if (r == CPL_ERROR_NONE) {
 #pragma omp critical(muse_processing_output_frames)
@@ -685,8 +722,8 @@ muse_processing_load_table(muse_processing *aProcessing, const char *aTag,
   @param  aHeader       the custom properties to be included in the header
                         (for aType == MUSE_TABLE_TYPE_CPL)
   @param  aTag          tag to apply for output frames, used as prefix
-  @param  aType         type of table to save
-                        (MUSE_TABLE_TYPE_CPL or MUSE_TABLE_TYPE_PIXTABLE)
+  @param  aType         type of table to save (MUSE_TABLE_TYPE_CPL,
+                        MUSE_TABLE_TYPE_MUSE, or MUSE_TABLE_TYPE_PIXTABLE)
   @return CPL_ERROR_NONE or the relevant cpl_error_code on error
 
   Save a table to disk. The filename consists on the prefix, a "-"
@@ -775,7 +812,8 @@ muse_processing_save_cimage(muse_processing *aProcessing, int aIFU,
   cpl_frame *frame = muse_processing_new_frame(aProcessing, aIFU,
                                                aHeader, aTag,
                                                CPL_FRAME_TYPE_IMAGE);
-  cpl_msg_info(__func__, "Saving image as %s", cpl_frame_get_filename(frame));
+  cpl_msg_info(__func__, "Saving image as \"%s\"",
+               cpl_frame_get_filename(frame));
   int r = cpl_image_save(aImage, cpl_frame_get_filename(frame),
                          CPL_TYPE_UNSPECIFIED, aHeader, CPL_IO_CREATE);
   if (r == CPL_ERROR_NONE) {
@@ -854,7 +892,8 @@ muse_processing_save_header(muse_processing *aProcessing, int aIFU,
   cpl_frame *frame = muse_processing_new_frame(aProcessing, aIFU,
                                                aHeader, aTag,
                                                CPL_FRAME_TYPE_IMAGE);
-  cpl_msg_info(__func__, "Saving header as %s", cpl_frame_get_filename(frame));
+  cpl_msg_info(__func__, "Saving header as \"%s\"",
+               cpl_frame_get_filename(frame));
   cpl_error_code rc = cpl_propertylist_save(aHeader,
                                             cpl_frame_get_filename(frame),
                                             CPL_IO_CREATE);
@@ -933,7 +972,8 @@ muse_processing_save_mask(muse_processing *aProcessing, int aIFU,
   cpl_frame *frame = muse_processing_new_frame(aProcessing, aIFU,
                                                aMask->header, aTag,
                                                CPL_FRAME_TYPE_IMAGE);
-  cpl_msg_info(__func__, "Saving mask as %s", cpl_frame_get_filename(frame));
+  cpl_msg_info(__func__, "Saving mask as \"%s\"",
+               cpl_frame_get_filename(frame));
   int r = muse_mask_save(aMask, cpl_frame_get_filename(frame));
   if (r == CPL_ERROR_NONE) {
 #pragma omp critical(muse_processing_output_frames)
@@ -1151,13 +1191,14 @@ muse_processing_sort_exposures(muse_processing *aProcessing)
         cpl_propertylist_delete(header);
         continue; /* skip on to the next frame */
       }
-      int ifu = muse_utils_get_ifu(header);
+      unsigned char ifu = muse_utils_get_ifu(header);
       if (!ifu) {
         cpl_msg_debug(__func__, "\"%s\" seems to contain merged data (no "
                       "EXTNAME=CHANnn)", filename);
       }
 #if DEBUG_EXPOSURES_SORT
-      cpl_msg_debug(__func__, "\"%s\": IFU %2d, DATE-OBS=\"%s\"", filename, ifu, date);
+      cpl_msg_debug(__func__, "\"%s\": IFU %2hhu, DATE-OBS=\"%s\"", filename,
+                    ifu, date);
 #endif
 
       /* loop through all exposures (=rows) in the table and compare the date */
@@ -1181,10 +1222,10 @@ muse_processing_sort_exposures(muse_processing *aProcessing)
 
       /* check, if table cell for this exposure is still empty and, *
        * if so, add the filename                                    */
-      snprintf(colname, 3, "%02d", ifu);
+      snprintf(colname, 3, "%02hhu", ifu);
       if (cpl_table_is_valid(exptable, colname, irow)) {
-        cpl_msg_warning(__func__, "we already have IFU %d of exposure %d (\"%s\")!"
-                        " Ignoring \"%s\"", ifu, irow+1,
+        cpl_msg_warning(__func__, "we already have IFU %2hhu of exposure %d "
+                        "(\"%s\")! Ignoring \"%s\"", ifu, irow+1,
                         cpl_table_get_string(exptable, colname, irow),
                         filename);
         cpl_propertylist_delete(header);
@@ -1214,19 +1255,19 @@ muse_processing_sort_exposures(muse_processing *aProcessing)
   }
   /* loop through all exposures and print the number of valid IFUs found */
   for (i = 0; i < cpl_table_get_nrow(exptable); i++) {
-    int nmerged = 0;
+    unsigned int nmerged = 0;
     if (cpl_table_is_valid(exptable, "00", i)) {
       nmerged++;
     }
-    int j, nvalid = 0;
-    for (j = 1; j <= kMuseNumIFUs; j++) {
-      snprintf(colname, 3, "%02d", j);
+    unsigned char ifu, nvalid = 0;
+    for (ifu = 1; ifu <= kMuseNumIFUs; ifu++) {
+      snprintf(colname, 3, "%02hhu", ifu);
       if (cpl_table_is_valid(exptable, colname, i)) {
         nvalid++;
       }
     } /* for i (table columns) */
-    cpl_msg_debug(__func__, "Data from exposure %2d is contained in %2d "
-                  "IFU%s/%d merged file%s", i+1, nvalid, nvalid == 1 ? "" : "s",
+    cpl_msg_debug(__func__, "Data from exposure %2d is contained in %2hhu "
+                  "IFU%s/%u merged file%s", i+1, nvalid, nvalid == 1 ? "" : "s",
                   nmerged, nmerged == 1 ? "" : "s");
   } /* for i (table rows) */
 
